@@ -1245,7 +1245,7 @@ def test_include_query_param():
         search_param=search_param,
         target=target
     )
-    assert include_param.to_url_param() == f"_include={resource}:{search_param}&{target}"
+    assert include_param.to_url_param() == f"_include={resource}:{search_param}:{target}"
 
     # reverse include
     include_param = IncludeParameter(
@@ -1254,7 +1254,7 @@ def test_include_query_param():
         target=target,
         reverse=True
     )
-    assert include_param.to_url_param() == f"_revinclude={resource}:{search_param}&{target}"
+    assert include_param.to_url_param() == f"_revinclude={resource}:{search_param}:{target}"
 
     # include with iterate & target
     include_param = IncludeParameter(
@@ -1264,7 +1264,7 @@ def test_include_query_param():
         iterate=True,
     )
 
-    assert include_param.to_url_param() == f"_include:iterate={resource}:{search_param}&{target}"
+    assert include_param.to_url_param() == f"_include:iterate={resource}:{search_param}:{target}"
 
     # parse from url snippet
 
@@ -1272,25 +1272,28 @@ def test_include_query_param():
     assert include_param.resource == resource
     assert include_param.search_param == search_param
 
-    include_param = IncludeParameter.from_url_param(f"_include={resource}:{search_param}&{target}")
+    include_param = IncludeParameter.from_url_param(f"_include={resource}:{search_param}:{target}")
     assert include_param.resource == resource
     assert include_param.search_param == search_param
     assert include_param.target == target
 
-    include_param = IncludeParameter.from_url_param(f"_revinclude={resource}:{search_param}&{target}")
+    include_param = IncludeParameter.from_url_param(f"_revinclude={resource}:{search_param}:{target}")
     assert include_param.resource == resource
     assert include_param.search_param == search_param
     assert include_param.target == target
     assert include_param.reverse is True
 
-    include_param = IncludeParameter.from_url_param(f"_include:iterate={resource}:{search_param}&{target}")
+    include_param = IncludeParameter.from_url_param(f"_include:iterate={resource}:{search_param}:{target}")
     assert include_param.resource == resource
     assert include_param.search_param == search_param
     assert include_param.target == target
     assert include_param.iterate is True
 
     with pytest.raises(ValueError):
-        include_param = IncludeParameter.from_url_param(f"_include:iterates={resource}:{search_param}&{target}")
+        include_param = IncludeParameter.from_url_param(f"_include:iterates={resource}:{search_param}:{target}")
+
+    with pytest.raises(ValueError):
+        include_param = IncludeParameter.from_url_param(f"_include:iterates={resource}:{search_param}:{target}:error")
 
 
 def test_reverse_chain_parameters():
@@ -1365,8 +1368,9 @@ def test_query_json(server):
     result = resp.limit(100)
     assert result.response
     assert isinstance(result.response, dict)
-    with pytest.raises(ValueError):
-        includes = result.included_resources
+
+    includes = result.included_resources
+    assert not includes
 
 
 def test_query_first(server):
@@ -1384,6 +1388,24 @@ def test_query_limit(server):
     assert len(result.resources) == 100
 
 
+def test_query_with_callback(server):
+    def callback1(resources):
+        print(len(resources))
+
+    server.query("Patient").all(page_callback=callback1, count=50)
+
+    def callback2():
+        print("callback2")
+
+    server.query("Patient").all(page_callback=callback2, count=200)
+
+    with pytest.raises(ValueError):
+        def callback3(a, b):
+            print("callback3")
+
+        server.query("Patient").all(page_callback=callback3, count=200)
+
+
 def test_query_response_resources(server):
     query = server.query("Patient")
     result = query.all()
@@ -1519,6 +1541,7 @@ def test_query_include(server, api_url):
     )
 
     query = query.include(include_param=include_param)
+    print(query)
     assert query.query_parameters.include_parameters[1].resource == query_resource
     assert query.query_parameters.include_parameters[1].target == "criteria"
 
@@ -1627,6 +1650,7 @@ def test_query_response_include(server):
     query = query.include(resource=query_resource, reference_param=search_param)
     response = query.all()
 
+    print(query)
     assert response.included_resources
     assert response.resources
     assert response.resources[0].resource_type == query_resource
@@ -1710,8 +1734,6 @@ def test_query_response_to_dfs(server):
     query = query.include(resource=query_resource, reference_param=search_param)
     response = query.all()
 
-    print(query)
-
     with pytest.raises(ValueError):
         response.to_dfs(format="invalid")
 
@@ -1719,5 +1741,3 @@ def test_query_response_to_dfs(server):
 
     assert len(dfs) > 1
     assert dfs[0].shape[0] > 0
-
-    print(response)
