@@ -1,8 +1,13 @@
 import os
+import uuid
+
 import pytest
 from fhir.resources import FHIRAbstractModel
 from unittest import mock
 
+from fhir.resources.condition import Condition
+from fhir.resources.encounter import Encounter
+from fhir.resources.reference import Reference
 from requests.auth import HTTPBasicAuth
 
 from fhir_kindling import FhirServer, FHIRQuery
@@ -11,7 +16,10 @@ from fhir.resources.organization import Organization
 from fhir.resources.address import Address
 from fhir.resources.bundle import Bundle, BundleEntry, BundleEntryRequest
 from fhir.resources.patient import Patient
+
+from fhir_kindling.fhir_query import FHIRQueryParameters
 from fhir_kindling.generators import PatientGenerator
+from fhir_kindling.util.references import reference_graph
 
 
 @pytest.fixture
@@ -309,7 +317,7 @@ def test_server_add_all(fhir_server: FhirServer):
 
 
 def test_query_all(fhir_server: FhirServer):
-    response = fhir_server.query(Patient, output_format="dict").all()
+    response = fhir_server.query(Patient.construct(), output_format="dict").all()
     print(response)
     assert response.response
 
@@ -326,7 +334,7 @@ def test_query_with_string_resource(fhir_server: FhirServer):
 
 
 def test_query_with_limit(fhir_server: FhirServer):
-    response = fhir_server.query(Patient, output_format="dict").limit(2)
+    response = fhir_server.query(Patient.construct(), output_format="dict").limit(2)
 
     assert response.response["entry"]
 
@@ -431,6 +439,92 @@ def test_custom_auth():
         server = FhirServer(api_address="https://fhir.test/fhir", auth=auth, client_id="test")
 
 
+def test_query_with_params(fhir_server: FhirServer):
+    params = FHIRQueryParameters(
+        resource="Condition"
+    )
+    query = fhir_server.query(query_parameters=params)
+    response = query.all()
+
+    assert response.resources
+
+
+def test_fhir_server_get(fhir_server: FhirServer):
+    patient = fhir_server.query("Patient").first().resources[0]
+
+    patient_by_reference = fhir_server.get(patient.relative_path())
+
+    assert patient_by_reference.id == patient.id
+
+
+def test_fhir_server_get_many(fhir_server: FhirServer):
+    patients = fhir_server.query("Patient").limit(10).resources
+
+    references = [p.relative_path() for p in patients]
+    patients_by_reference = fhir_server.get_many(references)
+
+    assert len(patients_by_reference) == len(patients)
+
+    for p, p2 in zip(patients, patients_by_reference):
+        assert p.id == p2.id
+
+
 def test_server_repr_str(fhir_server: FhirServer):
     print(fhir_server)
     assert fhir_server.__repr__() == fhir_server.__str__()
+
+
+def test_get(oidc_server: FhirServer):
+    response = oidc_server.query("Patient").first()
+    patient = oidc_server.get(f"Patient/{response.resources[0].id}")
+    assert patient
+    assert patient.id == response.resources[0].id
+
+    reference = Reference(reference=f"Patient/{response.resources[0].id}")
+    patient = oidc_server.get(reference)
+
+    assert patient
+    assert patient.id == response.resources[0].id
+
+
+def test_get_many(fhir_server: FhirServer):
+    patients = fhir_server.query("Patient").limit(10)
+    references = [p.relative_path() for p in patients.resources]
+    patients = fhir_server.get_many(references)
+    assert len(patients) == 10
+
+
+def test_resolve_reference_graph(fhir_server: FhirServer):
+    patients, patient_references = PatientGenerator(n=10, generate_ids=True).generate(references=True)
+    organization = Organization(name="Test", id="test-org")
+    practitioner = Organization(name="Practitioner", id="test-practitioner")
+    conditions = []
+    encounter = Encounter(
+        **{
+            "id": "test-encounter",
+            "status": "planned",
+            "class": {"code": "AMB", "system": "http://terminology.hl7.org/CodeSystem/v3-ActCode"}
+        }
+    )
+    for patient in patients:
+        patient.managingOrganization = {"reference": organization.relative_path()}
+        patient.generalPractitioner = [{"reference": practitioner.relative_path()}]
+        condition = Condition(subject={"reference": patient.relative_path()}, id=str(uuid.uuid4()))
+        condition.encounter = {"reference": encounter.relative_path()}
+        conditions.append(condition)
+
+    resources = patients + [organization, practitioner, encounter] + conditions
+    # print(resources)
+
+    hapi_server = FhirServer(api_address="http://localhost:8082/fhir")
+    response = fhir_server._transfer_resources(hapi_server, resources)
+
+
+def test_fhir_server_transfer(fhir_server: FhirServer):
+    conditions = fhir_server.query("Condition").limit(10)
+    hapi_server = FhirServer(api_address="http://localhost:8082/fhir")
+    response = fhir_server.transfer(hapi_server, conditions)
+
+    print(response)
+    assert response.destination_server == hapi_server.api_address
+    assert len(response.create_responses) >= 10
